@@ -16,7 +16,7 @@ import hwrt.utils as utils
 
 
 def unix_time():
-    return lambda: int(round(time.time() * 1000))
+    return int(round(time.time() * 1000))
 
 
 recording = []
